<?php
/**
 * Plugin Name: IP Block
 * Plugin URI:  https://mahdimohebi.ir/my-plugins/
 * Description: Block ip if attampts more than x to login , shows the reports and sends emails
 * Version:     1.8
 * Author:      Mahdi Mohebi
 * Author URI:  https://mahdimohebi.ir/
 * License:     GPLv2 or later
 * License URI: http://www.gnu.org/licenses/old-licenses/gpl-2.0.html
 * Text Domain: ip-block
 * Domain Path: /languages
 *
 */
if ( ! defined( 'ABSPATH' ) ) {
	die( 'Invalid request.' );
}
function ip_block_load_textdomain() {
  load_plugin_textdomain( 'ip-block', false, basename( dirname( __FILE__ ) ) . '/languages' ); 
} 
add_action( 'plugins_loaded', 'ip_block_load_textdomain' );
if ( ! class_exists( 'ip_block' ) ) :
class ip_block {
	private static $settings;
	private function __construct() {
	} 
	public static function init_actions() {
		register_activation_hook( __FILE__, array( __CLASS__, 'activate' ) );
		register_deactivation_hook(__FILE__, array( __CLASS__, 'deactivat'));
		register_uninstall_hook( __FILE__, array( __CLASS__, 'uninstall' ) );
		add_filter( 'cron_schedules',  array( __CLASS__ ,'add_intervals'));
		add_action( 'scheduled_ip_block_email',   array( __CLASS__ ,'send_report'));
		add_action( 'update_option_ip_block_settings',  array( __CLASS__,'ip_block_options_updated'), 10, 2 );
		add_action( 'init',  array( __CLASS__, 'ip_block_cpt' ));
		add_action( 'admin_menu', array( __CLASS__ , 'add_admin_menu' ) );
		add_action( 'admin_init', array( __CLASS__ , 'settings_init' ) );
		add_action( 'login_init', array( __CLASS__, 'check_and_lock' )  );
		add_action( 'wp_login_failed', array(__CLASS__,'login_failed'), 10, 1 ); 
		add_action( 'wp_login_failed', array(__CLASS__,'login_failed_send_warning'), 10, 1 );
		add_action( 'add_meta_boxes', array( __CLASS__ , 'add_metaboxes') );
		add_action( 'save_post',  array( __CLASS__ , 'save_metaboxes'), 1, 2 );
		add_filter('manage_edit-blocked_ip_columns', array( __CLASS__ , 'posts_column_country'));
		add_action('manage_posts_custom_column', array( __CLASS__ , 'posts_custom_column_country'),5,2);
		add_filter('manage_edit-blocked_ip_columns', array( __CLASS__ , 'posts_column_address'));
		add_action('manage_posts_custom_column', array( __CLASS__ , 'posts_custom_column_address'),5,2);
		add_filter('manage_edit-blocked_ip_columns', array( __CLASS__ , 'posts_column_attempts'));
		add_action('manage_posts_custom_column', array( __CLASS__ , 'posts_custom_column_attempts'),5,2);
		add_filter('manage_edit-blocked_ip_columns', array( __CLASS__ , 'posts_column_used_credentials'));
		add_action('manage_posts_custom_column', array( __CLASS__ , 'posts_custom_column_used_credentials'),5,2);
		add_filter( 'plugin_action_links_' . plugin_basename(__FILE__), array( __CLASS__, 'add_settings_link' ), 10, 2 );
		add_action( 'admin_enqueue_scripts', array( __CLASS__, 'enqueue_backend' ) );
		add_action( 'wp_enqueue_scripts', array( __CLASS__, 'enqueue_front' ) );
		$settings = self::get_settings();
		//if ( $settings['xxx'] ) {
		//} else {
		//}
	}
	
	public static function add_intervals($schedules) {
		$schedules['weekly'] = array(
			'interval' => 604800,
			'display' => __('Weekly')
		);
		$schedules['monthly'] = array(
			'interval' => 2635200,
			'display' => __('Monthly')
		);
		return $schedules;
	}
	 
	
	
	
	
	
	
	
	public static function add_admin_menu(  ) { 
		add_submenu_page(
			'edit.php?post_type=blocked_ip',
			__( 'IP Block Options', 'ip-block' ),
			__( 'Options', 'ip-block' ),
			'manage_options',
			'ip_block',
			array(__CLASS__,'ip_block_options_page')
		);
	}
	public static function settings_init(  ) { 
		register_setting( 'pluginPage', 'ip_block_settings' );
		add_settings_section(
			'ip_block_pluginPage_section', 
			__( 'Options', 'ip-block' ), 
			array( __CLASS__, 'ip_block_settings_section_callback'), 
			'pluginPage'
		);
		add_settings_field( 
			'ip_max_allowed_attempts', 
			__( 'Max Allowed Login Attempts', 'ip-block' ), 
			array( __CLASS__, 'ip_max_allowed_attempts_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
		add_settings_field( 
			'ip_reset_attempts_after', 
			__( 'Reset IP Login Attempts After ', 'ip-block' ), 
			array( __CLASS__, 'ip_reset_attempts_after_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
		add_settings_field( 
			'ip_send_warning', 
			__( 'Send Warning ?', 'ip-block' ), 
			array( __CLASS__, 'ip_send_warning_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
		add_settings_field( 
			'ip_send_warning_after_x_attempts', 
			__( 'Send warning After ', 'ip-block' ), 
			array( __CLASS__, 'ip_send_warning_after_x_attempts_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
		add_settings_field( 
			'ip_send_report', 
			__( 'Send Rport ?', 'ip-block' ), 
			array( __CLASS__, 'ip_send_report_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
		add_settings_field( 
			'ip_send_report_period', 
			__( 'Rport Period :', 'ip-block' ), 
			array( __CLASS__, 'ip_send_report_period_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
		add_settings_field( 
			'ip_send_email_to', 
			__( 'Send Emails To :', 'ip-block' ), 
			array( __CLASS__, 'ip_send_email_to_render'), 
			'pluginPage', 
			'ip_block_pluginPage_section' 
		);
	}
	public static function ip_max_allowed_attempts_render(  ) { 
		$options = self::get_settings();
		?>
		<input type="number" name="ip_block_settings[ip_max_allowed_attempts]" class="ip_max_allowed_attempts" value="<?php echo $options['ip_max_allowed_attempts']; ?>" />
		<?php
	}
	public static function ip_reset_attempts_after_render(  ) { 
		$options = self::get_settings();
		?>
		<input type="number" min="1" max="23" name="ip_block_settings[ip_reset_attempts_after]" class="ip_reset_attempts_after" value="<?php echo $options['ip_reset_attempts_after']; ?>" />
		<label ><?php _e( 'Hours',  'ip-block' ); ?></label>
		<?php
	}
	public static function ip_send_warning_render(  ) { 
		$options = self::get_settings();
		?>
		<input type='radio' name='ip_block_settings[ip_send_warning]' <?php if(isset($options['ip_send_warning'])){ checked( $options['ip_send_warning'], "yes" );} ?> value='yes'>
		<label ><?php _e( 'Yes',  'ip-block' ); ?></label>
		<br>
		<input type='radio' name='ip_block_settings[ip_send_warning]' <?php if(isset($options['ip_send_warning'])){ checked( $options['ip_send_warning'], "no" );} ?> value='no'>
		<label ><?php _e( 'No',  'ip-block' ); ?></label>
		<?php
	}
	public static function ip_send_warning_after_x_attempts_render(  ) { 
		$options = self::get_settings();
		?>
		<input type="number" name="ip_block_settings[ip_send_warning_after_x_attempts]" class="ip_send_warning_after_x_attempts" value="<?php echo $options['ip_send_warning_after_x_attempts']; ?>" />
		<label ><?php _e( 'Login Attempts',  'ip-block' ); ?></label>
		<?php
	}
	public static function ip_send_report_render(  ) { 
		$options = self::get_settings();
		?>
		<input type='radio' name='ip_block_settings[ip_send_report]' <?php if(isset($options['ip_send_report'])){ checked( $options['ip_send_report'], "yes" );} ?> value='yes'>
		<label ><?php _e( 'Yes',  'ip-block' ); ?></label>
		<br>
		<input type='radio' name='ip_block_settings[ip_send_report]' <?php if(isset($options['ip_send_report'])){ checked( $options['ip_send_report'], "no" );} ?> value='no'>
		<label ><?php _e( 'No',  'ip-block' ); ?></label>
		<?php
	}
	public static function ip_send_report_period_render(  ) { 
		$options = self::get_settings();
		?>
		<select name='ip_block_settings[ip_send_report_period]'>
		    <option value='hourly' <?php selected( $options['ip_send_report_period'], 'hourly ' ); ?>> <?php _e( 'Hourly',  'ip-block' ); ?></option>
			<option value='daily' <?php selected( $options['ip_send_report_period'], 'daily' ); ?>> <?php _e( 'Daily',  'ip-block' ); ?></option>
			<option value='weekly' <?php selected( $options['ip_send_report_period'], 'weekly' ); ?>><?php _e( 'Weekly',  'ip-block' ); ?></option>
			<option value='monthly' <?php selected( $options['ip_send_report_period'], 'monthly' ); ?>><?php _e( 'Monthly',  'ip-block' ); ?></option>
		</select>
		<?php
	}
	
	

	public static function ip_send_email_to_render(  ) { 
		$options = self::get_settings();
		?>
		<input type="text" name="ip_block_settings[ip_send_email_to]" class="ip_send_email_to" value="<?php echo $options['ip_send_email_to']; ?>" />
		<?php
	}
	public static function ip_block_settings_section_callback(  ) { 
		echo __( 'IP Block default options', 'ip-block' );
	}
	public static function ip_block_options_page(  ) { 
			?>
			<form action='options.php' method='post'>
				<h2><?php _e( 'IP BLOCK',  'ip-block' ); ?></h2>
				<?php
				settings_fields( 'pluginPage' );
				do_settings_sections( 'pluginPage' );
				submit_button();
				?>
			</form>
			<?php
	}
	public static function ip_block_cpt() {
		$labels = array(
			'name'                  => _x( 'IP Block',  'ip-block' ),
			'singular_name'         => _x( 'IP', 'Post Type Singular Name', 'ip-block' ),
			'menu_name'             => __( 'IP Block', 'ip-block' ),
			'name_admin_bar'        => __( 'IPes', 'ip-block' ),
			'archives'              => __( 'IP Archives', 'ip-block' ),
			'attributes'            => __( 'IP Attributes', 'ip-block' ),
			'parent_item_colon'     => __( 'Parent Item:', 'ip-block' ),
			'all_items'             => __( 'All IPes', 'ip-block' ),
			'add_new_item'          => __( 'Add New IP', 'ip-block' ),
			'add_new'               => __( 'Add IP', 'ip-block' ),
			'new_item'              => __( 'New IP', 'ip-block' ),
			'edit_item'             => __( 'Edit IP', 'ip-block' ),
			'update_item'           => __( 'Update IP', 'ip-block' ),
			'view_item'             => __( 'View IP', 'ip-block' ),
			'view_items'            => __( 'View IPes', 'ip-block' ),
			'search_items'          => __( 'Search IPes', 'ip-block' ),
			'not_found'             => __( 'Not found', 'ip-block' ),
			'not_found_in_trash'    => __( 'Not found in Trash', 'ip-block' ),
			'featured_image'        => __( 'Featured Image', 'ip-block' ),
			'set_featured_image'    => __( 'Set featured image', 'ip-block' ),
			'remove_featured_image' => __( 'Remove featured image', 'ip-block' ),
			'use_featured_image'    => __( 'Use as featured image', 'ip-block' ),
			'insert_into_item'      => __( 'Insert into IP', 'ip-block' ),
			'uploaded_to_this_item' => __( 'Uploaded to this IP', 'ip-block' ),
			'items_list'            => __( 'IPes list', 'ip-block' ),
			'items_list_navigation' => __( 'IPes list navigation', 'ip-block' ),
			'filter_items_list'     => __( 'Filter IPes list', 'ip-block' ),
		);
		$args = array(
			'label'                 => __( 'IP', 'ip-block' ),
			'labels'                => $labels,
			'supports'              => array( 'title' ),
			'hierarchical'          => false,
			'public'                => true,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'menu_position'         => 5,
			'show_in_admin_bar'     => true,
			'show_in_nav_menus'     => true,
			'can_export'            => true,
			'has_archive'           => false,
			'exclude_from_search'   => false,
			'publicly_queryable'    => false,
			'capability_type'       => 'page',
			'menu_icon'   => 'dashicons-lock',
		);
		register_post_type( 'blocked_ip', $args );
		$labels2 = array(
			'name'                  => _x( 'Attempt Block',  'ip-block' ),
			'singular_name'         => _x( 'Attempt', 'Post Type Singular Name', 'ip-block' ),
			'menu_name'             => __( 'Attempt Block', 'ip-block' ),
			'name_admin_bar'        => __( 'Attempts', 'ip-block' ),
			'archives'              => __( 'Attempt Archives', 'ip-block' ),
			'attributes'            => __( 'Attempt Attributes', 'ip-block' ),
			'parent_item_colon'     => __( 'Parent Item:', 'ip-block' ),
			'all_items'             => __( 'All Attempts', 'ip-block' ),
			'add_new_item'          => __( 'Add New Attempt', 'ip-block' ),
			'add_new'               => __( 'Add Attempt', 'ip-block' ),
			'new_item'              => __( 'New Attempt', 'ip-block' ),
			'edit_item'             => __( 'Edit Attempt', 'ip-block' ),
			'update_item'           => __( 'Update Attempt', 'ip-block' ),
			'view_item'             => __( 'View Attempt', 'ip-block' ),
			'view_items'            => __( 'View Attemptes', 'ip-block' ),
			'search_items'          => __( 'Search Attemptes', 'ip-block' ),
			'not_found'             => __( 'Not found', 'ip-block' ),
			'not_found_in_trash'    => __( 'Not found in Trash', 'ip-block' ),
			'featured_image'        => __( 'Featured Image', 'ip-block' ),
			'set_featured_image'    => __( 'Set featured image', 'ip-block' ),
			'remove_featured_image' => __( 'Remove featured image', 'ip-block' ),
			'use_featured_image'    => __( 'Use as featured image', 'ip-block' ),
			'insert_into_item'      => __( 'Insert into Attempt', 'ip-block' ),
			'uploaded_to_this_item' => __( 'Uploaded to this IP', 'ip-block' ),
			'items_list'            => __( 'Attempts list', 'ip-block' ),
			'items_list_navigation' => __( 'Attempts list navigation', 'ip-block' ),
			'filter_items_list'     => __( 'Filter Attempts list', 'ip-block' ),
		); 
		$args2 = array(
			'label'                 => __( 'IP', 'ip-block' ),
			'labels'                => $labels2,
			'supports'              => array( 'title' ),
			'hierarchical'          => false,
			'public'                => true,
			'show_ui'               => false,
			'show_in_menu'          => false,
			'menu_position'         => 5,
			'show_in_admin_bar'     => false,
			'show_in_nav_menus'     => false,
			'can_export'            => true,
			'has_archive'           => false,
			'exclude_from_search'   => false,
			'publicly_queryable'    => false,
			'capability_type'       => 'page',
			'menu_icon'   => 'dashicons-lock',
		);
		register_post_type( 'attempt', $args2 );
	} 
	public static function add_metaboxes() {
		add_meta_box( 'ip_block_meta_box_id', __( 'Data', 'ip-block' ), array( __CLASS__ , 'meta_box_display_callback'), 'blocked_ip' );
	}
	public static function meta_box_display_callback( $post ) {
		global $post;
		$options = self::get_settings();
		wp_nonce_field( basename( __FILE__ ), 'ip_block_fields' );
		$ip_address = get_post_meta( $post->ID, 'ip_address', true );
		$ip_country = get_post_meta( $post->ID, 'ip_country', true );
		$ip_human_address = get_post_meta( $post->ID, 'ip_human_address', true );
		$ip = get_post_meta( get_the_ID(), 'ip_address', true );
		if($ip!= ""){
			$query = new WP_Query( array( 
				'post_type' => 'attempt',
				'posts_per_page'=>-1,
				'post_status' => array( 'publish', 'private','draft' ),
				'meta_key'   => 'ip_address',
				'meta_value' => $ip, 
			)); 
		}
		?>
		<style type="text/css">
			.post_meta_extras p{margin: 20px;}
			.post_meta_extras label{display:block; margin-bottom: 10px;}
		</style>
		<div class="post_meta_extras">
		
			<p>
				<span  class='ip_lable_address'><?php _e( 'IP :',  'ip-block' ); ?></span >
				<input type="text" name="ip_address" value="<?php  echo $ip_address ;  ?>" class="ip_address_class">
			</p>
			
			<?php if($ip!= ""){  ?>
			<p>
				<span  class='ip_lable_address'><?php _e( 'Country :',  'ip-block' ); ?></span >
				<span  class='ip_lable_country'><?php  echo $ip_country ;  ?></span >
			</p>
			<?php }  ?>
			
			
			<?php if($ip!= ""){  ?>
			<p>
				<span  class='ip_lable_attempts_single'><?php _e( ' Attempts : ',  'ip-block' ); ?></span >
				<span class="ip_attempts_single" ><?php echo  $query->found_posts; ?></span>
				
			</p>
			<?php }  ?>
			
			<?php if($ip!= ""){  ?>
			<p>
				<label  class='ip_lable'> <?php _e( 'Used Credentials : ',  'ip-block' ); ?></label >
				<?php 

				ob_start();
				//echo  $query->found_posts;
				
				foreach($query->posts as $post){
					$login = get_post_meta( $post->ID, 'ip_used_login', true );
					$password = get_post_meta( $post->ID, 'ip_used_password', true );
					?>
					<div class="ip_used_credentials_list ucl_22" ><span style=""> <?php echo $login ?> </span><br><span style=""> <?php echo $password ?></span></div>
					<?php
				}
				echo ob_get_clean();
				?>
			</p>
			<?php }  ?>
			
			
			
			<?php if($ip!= ""){  ?>
			<p>
				<span  class='ip_lable_address'><?php _e( '	Address :',  'ip-block' ); ?></span >
				<span ><?php  echo $ip_human_address ;  ?></span >
			</p>
			<?php }  ?>
			
		<?php
	}
	public static function save_metaboxes( $post_id, $post ) {
		if ( ! current_user_can( 'edit_post', $post_id ) ) {
			return $post_id;
		}
		if ( ! isset( $_POST['ip_address'] ) || ! wp_verify_nonce( $_POST['ip_block_fields'], basename(__FILE__) ) ) {
			return $post_id;
		}
		$location = self::ip_info($_POST['ip_address'], "Location");
		$address = self::ip_info($_POST['ip_address'], "Address");
		$ip_blocks_meta['ip_address'] = esc_textarea( $_POST['ip_address'] );
		$ip_blocks_meta['ip_country'] = esc_textarea( $location['country'] );
		$ip_blocks_meta['ip_human_address'] = esc_textarea( $address );
		foreach ( $ip_blocks_meta as $key => $value ) :
			if ( 'revision' === $post->post_type ) {
				return;
			}
			if ( get_post_meta( $post_id, $key, false ) ) {
				update_post_meta( $post_id, $key, $value );
			} else {
				add_post_meta( $post_id, $key, $value);
			}
			if ( ! $value ) {
				delete_post_meta( $post_id, $key );
			}
		endforeach;
	}
	public static function posts_column_country($defaults){
		$defaults['country'] = __('Country','ip-block' );
		return $defaults;
	}
	public static function posts_custom_column_country($column_name, $id){
		if($column_name === 'country'){
			echo get_post_meta( get_the_ID(), 'ip_country', true );
		}
	}
	public static function posts_column_address($defaults){
		$defaults['address'] = __('Address','ip-block' );
		return $defaults;
	}
	public static function posts_custom_column_address($column_name, $id){
		if($column_name === 'address'){
			echo get_post_meta( get_the_ID(), 'ip_human_address', true );
		}
	}
	public static function posts_column_attempts($defaults){
		$defaults['attempts'] = __('Attempts','ip-block' );
		return $defaults;
	}
	public static function posts_custom_column_attempts($column_name, $id){
		$ip = get_post_meta( $id, 'ip_address', true );
		if($ip!= ""){
			if($column_name === 'attempts'){
				$query = new WP_Query( array( 
					'post_type' => 'attempt',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'meta_key'   => 'ip_address',
					'meta_value' => $ip,
				)); 
				echo  $query->found_posts;
			}
		}
	}
	public static function posts_column_used_credentials($defaults){
		$defaults['credentials'] = __('Credentials','ip-block' );
		return $defaults;
	}
	public static function posts_custom_column_used_credentials($column_name, $id){
		$ip = get_post_meta( $id, 'ip_address', true );
		if($ip!= ""){
			if($column_name === 'credentials'){
				$query = new WP_Query( array( 
					'post_type' => 'attempt',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'meta_key'   => 'ip_address',
					'meta_value' => $ip, 
				)); 
				ob_start();
				 
				
				foreach($query->posts as $post){
					//$post->ID
					$login = get_post_meta( $post->ID, 'ip_used_login', true );
					$password = get_post_meta( $post->ID, 'ip_used_password', true );
					?>
						<div class="ip_used_credentials_list" ><span style=""> <?php echo $login ?> </span><br><span style=""> <?php echo $password ?></span></div>
						<?php
				}
				echo ob_get_clean(); 
				
				 
			}
		}
	}
	private static function get_settings() {
		self::$settings = get_option( 'ip_block_settings' );
		return self::$settings;
	}
	public static function get_ip() {
		$ip = '';
		if ( isset( $_SERVER ) ) {
			$sever_vars = array( 'HTTP_X_REAL_IP', 'HTTP_CLIENT_IP', 'HTTP_X_FORWARDED_FOR', 'REMOTE_ADDR' );
			foreach( $sever_vars as $var ) {
				if ( isset( $_SERVER[ $var ] ) && ! empty( $_SERVER[ $var ] ) ) {
					if ( filter_var( $_SERVER[ $var ], FILTER_VALIDATE_IP ) ) {
						$ip = $_SERVER[ $var ];
						break;
					} else { /* if proxy */
						$ip_array = explode( ',', $_SERVER[ $var ] );
						if ( is_array( $ip_array ) && ! empty( $ip_array ) && filter_var( $ip_array[0], FILTER_VALIDATE_IP ) ) {
							$ip = $ip_array[0];
							break;
						}
					}
				}
			}
		}
		return $ip; 
	}
	public static function is_limit_login_ok($ip) {
		return true;
	} 
	public static function is_ip_blocked( $ip ) {
		$settings = self::get_settings();
		$query = new WP_Query( array( 
			'post_type' => 'blocked_ip',
			'posts_per_page'=>-1,
			'post_status' => array( 'publish', 'private','draft' ),
			'meta_key'   => 'ip_address',
			'meta_value' => $ip,
		)); 
		if($query->found_posts > 0){
			return true;
		}else{
			return false;
		}
	}
	public static function record_new_attempt( $ip ) {
	}
	public static function add_to_black_list_if_needed( $ip,$attempt_number ) { 
		$settings = self::get_settings();
		if($attempt_number >= $settings['ip_max_allowed_attempts'] ){
			$id = wp_insert_post(array(
			  'post_title'=>$ip , 
			  'post_type'=>'blocked_ip', 
			  'post_content'=>$ip,
			  'post_status'=>'publish',
			));
			$location = self::ip_info($ip, "Location");
			$address = self::ip_info($ip, "Address");
			update_post_meta( $id , 'ip_address', $ip );
			update_post_meta( $id , 'ip_country', $location['country'] );
			update_post_meta( $id , 'ip_human_address', $address );
		}
	}
	public static function get_login_attempt_number( $ip ) {
		$settings = self::get_settings();
		$query = new WP_Query( array( 
			'post_type' => 'attempt',
			'posts_per_page'=>-1,
			'post_status' => array( 'publish', 'private','draft' ),
			'meta_key'   => 'ip_address',
			'meta_value' => $ip,
			'date_query' => array(
				 array( 
					   'after' => $settings['ip_reset_attempts_after'].' hours ago'
					   )
			)
		)); 
		return $query->found_posts;
	}
	public static function check_and_lock(){
		$ip = self::get_ip();
		if ( is_user_logged_in() || !self::is_ip_blocked($ip) ){
			return;
		}
		if ( self::is_ip_blocked($ip) )
		{
			header('HTTP/1.0 403 Forbidden');
			exit;
		}
	}
	public static function login_failed( $array ) {
		$user_login = $_POST['log'];
		$password =	$_POST['pwd'];
		$ip = self::get_ip();
		$id = wp_insert_post(array(
		  'post_title'=>$ip , 
		  'post_type'=>'attempt', 
		  'post_content'=>$ip,
		  'post_status'=>'publish',
		));
		$location = self::ip_info($ip, "Location");
		$address = self::ip_info($ip, "Address");
		update_post_meta( $id , 'ip_address', $ip );
		update_post_meta( $id , 'ip_country', $location['country'] );
		update_post_meta( $id , 'ip_human_address', $address );
		update_post_meta( $id , 'ip_used_login', $user_login );
		update_post_meta( $id , 'ip_used_password', $password );
		$attempt_number = self::get_login_attempt_number($ip);
		self::add_to_black_list_if_needed($ip,$attempt_number);
	}
	public static function login_failed_send_warning( $array ) {
		//self::send_report();
		function ip_block__set_content_type(){
			return "text/html";
		}
		add_filter( 'wp_mail_content_type','ip_block__set_content_type' );
				
		
		$settings = self::get_settings();
		if($settings['ip_send_warning'] == 'yes'){
			$ip = self::get_ip();
			$attempt_number = self::get_login_attempt_number($ip);
			if((int)$attempt_number >= (int)$settings['ip_send_warning_after_x_attempts']){
				$location = self::ip_info($ip, "Location");
				$country = $location['country'] ;
				$address = self::ip_info($ip, "Address");
				$query = new WP_Query( array( 
					'post_type' => 'attempt',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'meta_key'   => 'ip_address',
					'meta_value' => $ip, 
				)); 
				ob_start();
				?>
				<ul>
				  <li  style="color: black;"><?php _e( 'IP : ',  'ip-block' ); echo $ip;?></li>
				  <li style="color: black;"><?php _e( 'Country : ',  'ip-block' ); echo $country;?></li>
				  <li style="color: black;"><?php _e( 'Address : ',  'ip-block' ); echo $address;?></li>
				  <li style="color: black;"><?php _e( 'Attempts : ',  'ip-block' ); echo $attempt_number;?></li>
				</ul>
				<?php				
				$disc  = ob_get_clean();
				ob_start();
				foreach($query->posts as $post){
					//$post->ID
					$login = get_post_meta( $post->ID, 'ip_used_login', true );
					$password = get_post_meta( $post->ID, 'ip_used_password', true );
					?>
					<tr>
						<td class="pc-fb-font" style="padding: 10px ; color: #282828; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 13px; border-bottom: 1px solid #E5E5E5" valign="top" align="left">
						<?php echo get_the_date( 'H:i:s' ,$post->ID); ?>
						</td>
						<td class="pc-fb-font" style="padding: 10px; color: #282828; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 13px; border-bottom: 1px solid #E5E5E5" valign="top" align="left">
						  <?php echo $login ?>
						</td>
						<td class="pc-fb-font" style="padding: 10px; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 13px; border-bottom: 1px solid #E5E5E5; color: red;" valign="top" align="left"> 
						  <?php echo $password ?>
						</td>
					</tr>
					<?php  
				}
				$tr_loop_item =  ob_get_clean();
				$to = $settings['ip_send_email_to'];
				ob_start();
				_e( 'Unusual Login Attempt By : ',  'ip-block' ); 
				echo $ip . ' ' . $location['country'] ;
				$subject = ob_get_clean(); 
				ob_start();
				?>
				  <table class="pc-email-body" width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation" style="table-layout: fixed;">
					<tbody>
					  <tr>
						<td class="pc-email-body-inner" align="center" valign="top">
						  <table class="pc-email-container" width="100%" align="center" border="0" cellpadding="0" cellspacing="0" role="presentation" style="margin: 0 auto; max-width: 620px;">
							<tbody>
							  <tr>
								<td align="left" valign="top" style="padding: 0 10px;">
								  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
									<tbody>
									  <tr>
										<td height="20" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
									<tbody>
									  <tr>
										<td background="images/warning-Y6S.jpg" bgcolor="#1B1B1B" valign="top" style="background-color: #1B1B1B; background-image: url('images/warning-Y6S.jpg'); background-position: center; background-repeat: no-repeat; background-size: cover; border-radius: 8px; box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.1)">
										  <table width="100%" border="0" cellspacing="0" cellpadding="0" role="presentation">
											<tbody>
											  <tr>
												<td class="pc-sm-p-24-20-30 pc-xs-p-15-10-20" valign="top" style="padding: 24px 30px 40px;">
												  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
													<tbody>
													  <tr>
														<td valign="top" style="padding: 10px;">
														  <a href="http://example.com" style="text-decoration: none;"><img src="images/5a81af7d9123fa7bcc9b0793-MHg.png" width="94" height="94" alt="" style="max-width: 100%; height: auto; border: 0; line-height: 100%; outline: 0; -ms-interpolation-mode: bicubic; font-size: 14px; color: #ffffff;"></a>
														</td>
													  </tr>
													  <tr>
														<td class="pc-xs-h-100" height="0" style="line-height: 1px; font-size: 1px">&nbsp;</td>
													  </tr>
													  <tr>
														<td class="pc-fb-font" valign="top" style="padding: 0 10px;">
														  <a style="text-decoration: none; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14px; font-weight: 500; color: #ec7373">
														  <?php echo  date( 'Y-m-d H:i:s', current_time( 'timestamp', 0 ) ); ?>
														  </a>
														</td>
													  </tr>
													  <tr>
														<td class="pc-xs-fs-30 pc-xs-lh-42 pc-fb-font" valign="top" style="padding: 13px 10px 0; letter-spacing: -0.7px; line-height: 46px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 36px; font-weight: 800; color: #f90000">
														<?php _e( 'Lgin Attempts WARNING',  'ip-block' );?>
														</td>
													  </tr>
													</tbody>
												  </table>
												</td>
											  </tr>
											</tbody>
										  </table>
										</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellspacing="0" cellpadding="0" role="presentation">
									<tbody>
									  <tr>
										<td height="8" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								  <table border="0" cellpadding="0" cellspacing="0" role="presentation" width="100%">
									<tbody>
									  <tr>
										<td class="pc-sm-p-30-20 pc-xs-p-25-10" style="padding: 40px 30px; background: #dee7ea59; border-radius: 8px; box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.1)" bgcolor="#dee7ea59" valign="top">
										  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
											<tbody>
											  <tr>
												<td class="pc-sm-fs-30 pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 24px; font-weight: 800; line-height: 46px; letter-spacing: -0.6px; color: #151515; padding: 0 10px" valign="top">
												<?php _e( 'Description',  'ip-block' ); ?>
												</td>
											  </tr>
											  <tr>
												<td height="5" style="line-height: 1px; font-size: 1px;">&nbsp;</td>
											  </tr>
											</tbody>
											<tbody>
											  <tr>
												<td class="pc-sm-fs-18 pc-xs-fs-16 pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 20px; line-height: 30px; letter-spacing: -0.2px; color: #9B9B9B; padding: 0 10px" valign="top">
												<?php echo $disc; ?>
												</td>
											  </tr>
											  <tr>
												<td height="10" style="line-height: 1px; font-size: 1px;">&nbsp;</td>
											  </tr>
											</tbody>
											<tbody>
											  <tr>
												<td style="padding: 0 10px;" valign="top">
												  <table border="0" cellpadding="0" cellspacing="0" role="presentation" width="100%">
													<tbody>
													  <tr>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 20px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14x; padding: 10px; border-bottom: 1px solid #E5E5E5; width: auto; color: #151515" align="left"><?php _e( 'Time',  'ip-block' )?></th>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 20px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14px; padding:  10px; border-bottom: 1px solid #E5E5E5; width: auto; color: #151515;" align="left"><?php _e( 'UserName',  'ip-block' )?></th>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 20px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14px; border-bottom: 1px solid #E5E5E5; padding:  10px; width: auto; color: #151515;" align="left"><?php _e( 'Password',  'ip-block' )?></th>
													  </tr>
													</tbody>
													<tbody>
													<?php echo $tr_loop_item ; ?>
													</tbody>
												  </table>
												</td>
											  </tr>
											</tbody>
										  </table>
										</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellspacing="0" cellpadding="0" role="presentation">
									<tbody>
									  <tr>
										<td height="8" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								  <table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
									<tbody>
									  <tr>
										<td class="pc-sm-p-21-10-14 pc-xs-p-5-0" style="padding: 21px 20px 14px 20px; background-color: #1B1B1B; border-radius: 8px; box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.1)" valign="top" bgcolor="#1B1B1B" role="presentation">
										  <table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
											<tbody>
											  <tr>
												<td style="font-size: 0;" valign="top">
												  <div class="pc-sm-mw-100pc" style="display: inline-block; width: 100%; max-width: 280px; vertical-align: top;">
													<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
													  <tbody>
														<tr>
														  <td style="padding: 20px;" valign="top">
															<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
															  <tbody>
																<tr>
																  <td class="pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 18px; font-weight: 500; line-height: 24px; letter-spacing: -0.2px; color: #ffffff;" valign="top">
																  <?php echo get_bloginfo( 'name' ); ?>
																  </td>
																</tr>
																<tr>
																  <td height="11" style="line-height: 1px; font-size: 1px;">&nbsp;</td>
																</tr>
															  </tbody>
															  <tbody>
															  </tbody>
															</table>
														  </td>
														</tr>
													  </tbody>
													</table>
												  </div>
												  <div class="pc-sm-mw-100pc" style="display: inline-block; width: 100%; max-width: 280px; vertical-align: top;">
													<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
													  <tbody>
														<tr>
														  <td style="padding: 20px;" valign="top">
															<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
															  <tbody>
																<tr>
																  <td class="pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14px; font-weight: 500; line-height: 24px;" valign="top">
																	<a href="<?php echo get_site_url(); ?>" style="text-decoration: none; color: #1595E7;"><?php echo get_site_url(); ?></a>
																  </td>
																</tr>
															  </tbody>
															</table>
														  </td>
														</tr>
													  </tbody>
													</table>
												  </div>
												</td>
											  </tr>
											</tbody>
										  </table>
										</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
									<tbody>
									  <tr>
										<td height="20" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								</td>
							  </tr>
							</tbody>
						  </table>
						</td>
					  </tr>
					</tbody>
				  </table>
				  <div class="pc-gmail-fix" style="white-space: nowrap; font: 15px courier; line-height: 0;">&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; </div>
								
				<?php
				
				$message = ob_get_clean();
				wp_mail($to, $subject, $message );
			}
		}
	}
	public static function ip_info($ip = NULL, $purpose = "location", $deep_detect = TRUE) {
		$output = NULL;
		if (filter_var($ip, FILTER_VALIDATE_IP) === FALSE) {
			$ip = $_SERVER["REMOTE_ADDR"];
			if ($deep_detect) {
				if (filter_var(@$_SERVER['HTTP_X_FORWARDED_FOR'], FILTER_VALIDATE_IP))
					$ip = $_SERVER['HTTP_X_FORWARDED_FOR'];
				if (filter_var(@$_SERVER['HTTP_CLIENT_IP'], FILTER_VALIDATE_IP))
					$ip = $_SERVER['HTTP_CLIENT_IP'];
			}
		}
		$purpose    = str_replace(array("name", "\n", "\t", " ", "-", "_"), NULL, strtolower(trim($purpose)));
		$support    = array("country", "countrycode", "state", "region", "city", "location", "address");
		$continents = array(
			"AF" => "Africa",
			"AN" => "Antarctica",
			"AS" => "Asia",
			"EU" => "Europe",
			"OC" => "Australia (Oceania)",
			"NA" => "North America",
			"SA" => "South America"
		);
		if (filter_var($ip, FILTER_VALIDATE_IP) && in_array($purpose, $support)) {
			$ipdat = @json_decode(file_get_contents("http://www.geoplugin.net/json.gp?ip=" . $ip));
			if (@strlen(trim($ipdat->geoplugin_countryCode)) == 2) {
				switch ($purpose) {
					case "location":
						$output = array(
							"city"           => @$ipdat->geoplugin_city,
							"state"          => @$ipdat->geoplugin_regionName,
							"country"        => @$ipdat->geoplugin_countryName,
							"country_code"   => @$ipdat->geoplugin_countryCode,
							"continent"      => @$continents[strtoupper($ipdat->geoplugin_continentCode)],
							"continent_code" => @$ipdat->geoplugin_continentCode
						);
						break;
					case "address":
						$address = array($ipdat->geoplugin_countryName);
						if (@strlen($ipdat->geoplugin_regionName) >= 1)
							$address[] = $ipdat->geoplugin_regionName;
						if (@strlen($ipdat->geoplugin_city) >= 1)
							$address[] = $ipdat->geoplugin_city;
						$output = implode(", ", array_reverse($address));
						break;
					case "city":
						$output = @$ipdat->geoplugin_city;
						break;
					case "state":
						$output = @$ipdat->geoplugin_regionName;
						break;
					case "region":
						$output = @$ipdat->geoplugin_regionName;
						break;
					case "country":
						$output = @$ipdat->geoplugin_countryName;
						break;
					case "countrycode":
						$output = @$ipdat->geoplugin_countryCode;
						break;
				}
			}
		}
		return $output;
	}
	public static function enqueue_backend() {
		wp_enqueue_script("jquery");
		wp_enqueue_style('back_css', plugins_url('assets/back.css',__FILE__ ));
		wp_enqueue_script('back_js', plugins_url('assets/back.js',__FILE__ ));
	}
	public static function enqueue_front(){
		wp_enqueue_script("jquery");
		wp_enqueue_script('front_js', plugins_url('assets/front.js',__FILE__ ));
		$data = array('name_1'   => admin_url( 'admin-ajax.php' ),'a_value' => '10');
		wp_localize_script('front_js', 'pefix_handel', $data);
		wp_enqueue_style('front_css', plugins_url('assets/front.css',__FILE__ ));
		wp_enqueue_style('front_css_rtl', plugins_url('assets/front_rtl.css',__FILE__ ));
	}
	public static function add_settings_link( $links, $file ) {
		$settings = self::get_settings();
		if ( current_user_can( 'manage_options' ) ) {
			$url = admin_url( 'edit.php?post_type=blocked_ip&page=ip_block' );
			$links = (array) $links;
			$links[] = sprintf( '<a href="%s">%s</a>', $url, __( 'Settings', 'ip-block' ) );
		}
		return $links;
	}
	public static function activate() {
		if (! wp_next_scheduled ( 'scheduled_ip_block_email' )) {
			$settings = self::get_settings();
			wp_schedule_event(time(), $settings['ip_send_report_period'], 'scheduled_ip_block_email');
		}
		$settings = array(
			'ip_max_allowed_attempts' => get_option( 'ip_max_allowed_attempts','6' ),
			'ip_reset_attempts_after' => get_option( 'ip_reset_attempts_after','23' ),
			'ip_send_warning' => get_option( 'ip_send_warning','yes' ),
			'ip_send_warning_after_x_attempts' => get_option( 'ip_send_warning_after_x_attempts','3' ),
			'ip_send_report' => get_option( 'ip_send_report','yes' ),
			'ip_send_report_period' => get_option( 'ip_send_report_period','weekly' ),
			'ip_send_email_to' => get_option( 'ip_send_email_to',get_option( 'admin_email' ) ),
		);
		add_option( 'ip_block_settings', $settings );
	}
	public static function deactivat() {
		wp_clear_scheduled_hook('scheduled_ip_block_email');
	}
	

	public static function uninstall() {
		delete_option( 'ip_block_settings' );
	}
	public static function send_report() {
		function ip_block__set_content_type_2(){
			return "text/html";
		}
		add_filter( 'wp_mail_content_type','ip_block__set_content_type_2' );
				
		
		$settings = self::get_settings();
		$ip_send_report_period = $settings['ip_send_report_period'];
		if($settings['ip_send_report'] == 'yes'){
			
				
			if($ip_send_report_period == 'hourly'){
				$query = new WP_Query( array( 
					'post_type' => 'blocked_ip',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'date_query' => array(
						 array( 
							   'after' =>'1 hours ago'
							   )
					)
				)); 
			}elseif($ip_send_report_period == 'daily'){
				$query = new WP_Query( array( 
					'post_type' => 'blocked_ip',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'date_query' => array(
						 array( 
							   'after' =>'1 days ago'
							   )
					)
				)); 
			}elseif($ip_send_report_period == 'weekly'){
				$query = new WP_Query( array( 
					'post_type' => 'blocked_ip',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'date_query' => array(
						 array( 
							   'after' =>'1 week ago'
							   )
					)
				)); 
			}elseif($ip_send_report_period == 'monthly'){
				$query = new WP_Query( array( 
					'post_type' => 'blocked_ip',
					'posts_per_page'=>-1,
					'post_status' => array( 'publish', 'private','draft' ),
					'date_query' => array(
						 array( 
							   'after' =>'1 month ago'
							   )
					)
				)); 
			}
			
			if ($query->have_posts()){
				$tr_loop_item = '';
				foreach($query->posts as $post){//آی پی
					
		
					$ip_address = get_post_meta( $post->ID, 'ip_address', true );
					$ip_country = get_post_meta( $post->ID, 'ip_country', true );
					$ip_human_address = get_post_meta( $post->ID, 'ip_human_address', true );
					$attempt_query = new WP_Query( array( 
						'post_type' => 'attempt',
						'posts_per_page'=>-1,
						'post_status' => array( 'publish', 'private','draft' ),
						'meta_key'   => 'ip_address',
						'meta_value' => $ip_address, 
					)); 
					ob_start();//disc
						?>
						<ul>
						  <li  style="color: black;"><?php _e( 'Bloked IP Count : ',  'ip-block' ); echo $attempt_query->found_posts; ?></li>
						</ul>
						<?php				
					$disc  = ob_get_clean();
					ob_start();//credentials
						foreach($attempt_query->posts as $post_2){
							$login = get_post_meta( $post_2->ID, 'ip_used_login', true );
							$password = get_post_meta( $post_2->ID, 'ip_used_password', true );
							?><div style="border:1px solid grey ; padding:5px; margin:2px;    text-align: left;"><span><?php echo $login ?></span><br><span><?php echo $password ?></span></div><?php
						}
					$credentials  = ob_get_clean();
					ob_start();//tr_loop_item
					?>
					<tr>
						<td class="pc-fb-font" style="padding: 8px ; color: #282828; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 10px; border-bottom: 1px solid #E5E5E5" valign="top" align="left">
							<?php echo $ip_address ?>
						</td>
						<td class="pc-fb-font" style="padding: 8px ; color: #282828; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 10px; border-bottom: 1px solid #E5E5E5" valign="top" align="left">
						  <?php echo get_the_date( 'Y-m-d H:i:s' ,$post->ID); ?>
						</td>
						<td class="pc-fb-font" style="padding: 8px ; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 10px; border-bottom: 1px solid #E5E5E5; color: red;" valign="top" align="left"> 
						  <?php echo $ip_country ?>
						</td>
						<td class="pc-fb-font" style="padding: 8px ; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 10px; border-bottom: 1px solid #E5E5E5; color: red;" valign="top" align="left"> 
						  <?php echo $query->found_posts ?>
						</td>
						<td class="pc-fb-font" style="padding: 8px ; letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 10px; border-bottom: 1px solid #E5E5E5; color: red;" valign="top" align="left"> 
						  <?php echo $credentials ?>
						</td>
					</tr>
					<?php  
					$tr_loop_item .= ob_get_clean();
				}
				
				$to = $settings['ip_send_email_to'];
				ob_start();//subject
				echo  get_bloginfo( 'name' );
				echo ' - ';
				_e( 'Block IP Report : ',  'ip-block' ); 
				$subject = ob_get_clean(); 
				ob_start();//massage
				?>
				  <table class="pc-email-body" width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation" style="table-layout: fixed;">
					<tbody>
					  <tr> 
						<td class="pc-email-body-inner" align="center" valign="top">
						  <table class="pc-email-container" width="100%" align="center" border="0" cellpadding="0" cellspacing="0" role="presentation" style="margin: 0 auto; max-width: 620px;">
							<tbody>
							  <tr>
								<td align="left" valign="top" style="padding: 0 10px;">
								  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
									<tbody>
									  <tr>
										<td height="20" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
									<tbody>
									  <tr>
										<td background="images/warning-Y6S.jpg" bgcolor="#1B1B1B" valign="top" style="background-color: #1B1B1B; background-image: url('images/warning-Y6S.jpg'); background-position: center; background-repeat: no-repeat; background-size: cover; border-radius: 8px; box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.1)">
										  <table width="100%" border="0" cellspacing="0" cellpadding="0" role="presentation">
											<tbody>
											  <tr>
												<td class="pc-sm-p-24-20-30 pc-xs-p-15-10-20" valign="top" style="padding: 24px 30px 40px;">
												  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
													<tbody>
													  <tr>
														<td valign="top" style="padding: 10px;">
														  <a href="http://example.com" style="text-decoration: none;"><img src="images/5a81af7d9123fa7bcc9b0793-MHg.png" width="94" height="94" alt="" style="max-width: 100%; height: auto; border: 0; line-height: 100%; outline: 0; -ms-interpolation-mode: bicubic; font-size: 14px; color: #ffffff;"></a>
														</td>
													  </tr>
													  <tr>
														<td class="pc-xs-h-100" height="0" style="line-height: 1px; font-size: 1px">&nbsp;</td>
													  </tr>
													  <tr>
														<td class="pc-fb-font" valign="top" style="padding: 0 10px;">
														  <a style="text-decoration: none; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14px; font-weight: 500; color: #ec7373">
														  <?php echo  date( 'Y-m-d H:i:s', current_time( 'timestamp', 0 ) ); ?>
														  </a>
														</td>
													  </tr>
													  <tr>
														<td class="pc-xs-fs-30 pc-xs-lh-42 pc-fb-font" valign="top" style="padding: 13px 10px 0; letter-spacing: -0.7px; line-height: 46px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 36px; font-weight: 800; color: #f90000">
														<?php _e( 'Security Report',  'ip-block' );?>
														</td>
													  </tr>
													</tbody>
												  </table>
												</td>
											  </tr>
											</tbody>
										  </table>
										</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellspacing="0" cellpadding="0" role="presentation">
									<tbody>
									  <tr>
										<td height="8" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								  <table border="0" cellpadding="0" cellspacing="0" role="presentation" width="100%">
									<tbody>
									  <tr>
										<td class="pc-sm-p-30-20 pc-xs-p-25-10" style="padding: 40px 30px; background: #dee7ea59; border-radius: 8px; box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.1)" bgcolor="#dee7ea59" valign="top">
										  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
											
											<tbody>
											  <tr>
												<td class="pc-sm-fs-18 pc-xs-fs-16 pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 20px; line-height: 30px; letter-spacing: -0.2px; color: #9B9B9B; padding: 0 10px" valign="top">
												<?php echo $disc; ?>
												</td>
											  </tr>
											  <tr>
												<td height="25" style="line-height: 1px; font-size: 1px;">&nbsp;</td>
											  </tr>
											</tbody>
											<tbody>
											  <tr>
												<td style="padding: 0 10px;" valign="top">
												  <table border="0" cellpadding="0" cellspacing="0" role="presentation" width="100%">
													<tbody>
													  <tr>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 12px; border-bottom: 1px solid #E5E5E5; padding: 10px 0;  color: #151515" align="left"><?php _e( 'IP',  'ip-block' )?></th>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 12px; border-bottom: 1px solid #E5E5E5; padding: 10px 0;  color: #151515;" align="left"><?php _e( 'Date',  'ip-block' )?></th>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 12px; border-bottom: 1px solid #E5E5E5; padding: 10px 0;  color: #151515;" align="left"><?php _e( 'Country',  'ip-block' )?></th>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 12px; border-bottom: 1px solid #E5E5E5; padding: 10px 0;  color: #151515;" align="left"><?php _e( 'Attempts',  'ip-block' )?></th>
														<th class="pc-fb-font" style="letter-spacing: -0.2px; line-height: 26px; font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 12px; border-bottom: 1px solid #E5E5E5; padding: 10px 0;  color: #151515;" align="left"><?php _e( 'Credentials',  'ip-block' )?></th>
													  </tr>
													</tbody>
													<tbody>
													<?php echo $tr_loop_item ; ?>
													</tbody>
												  </table>
												</td>
											  </tr>
											</tbody>
										  </table>
										</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellspacing="0" cellpadding="0" role="presentation">
									<tbody>
									  <tr>
										<td height="8" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								  <table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
									<tbody>
									  <tr>
										<td class="pc-sm-p-21-10-14 pc-xs-p-5-0" style="padding: 21px 20px 14px 20px; background-color: #1B1B1B; border-radius: 8px; box-shadow: 0 2px 4px 0 rgba(0, 0, 0, 0.1)" valign="top" bgcolor="#1B1B1B" role="presentation">
										  <table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
											<tbody>
											  <tr>
												<td style="font-size: 0;" valign="top">
												  <div class="pc-sm-mw-100pc" style="display: inline-block; width: 100%; max-width: 280px; vertical-align: top;">
													<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
													  <tbody>
														<tr>
														  <td style="padding: 20px;" valign="top">
															<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
															  <tbody>
																<tr>
																  <td class="pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 18px; font-weight: 500; line-height: 24px; letter-spacing: -0.2px; color: #ffffff;" valign="top">
																  <?php echo get_bloginfo( 'name' ); ?>
																  </td>
																</tr>
																<tr>
																  <td height="11" style="line-height: 1px; font-size: 1px;">&nbsp;</td>
																</tr>
															  </tbody>
															  <tbody>
															  </tbody>
															</table>
														  </td>
														</tr>
													  </tbody>
													</table>
												  </div>
												  <div class="pc-sm-mw-100pc" style="display: inline-block; width: 100%; max-width: 280px; vertical-align: top;">
													<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
													  <tbody>
														<tr>
														  <td style="padding: 20px;" valign="top">
															<table border="0" cellpadding="0" cellspacing="0" width="100%" role="presentation">
															  <tbody>
																<tr>
																  <td class="pc-fb-font" style="font-family: 'Fira Sans', Helvetica, Arial, sans-serif; font-size: 14px; font-weight: 500; line-height: 24px;" valign="top">
																	<a href="<?php echo get_site_url(); ?>" style="text-decoration: none; color: #1595E7;"><?php echo get_site_url(); ?></a>
																  </td>
																</tr>
															  </tbody>
															</table>
														  </td>
														</tr>
													  </tbody>
													</table>
												  </div>
												</td>
											  </tr>
											</tbody>
										  </table>
										</td>
									  </tr>
									</tbody>
								  </table>
								  <table width="100%" border="0" cellpadding="0" cellspacing="0" role="presentation">
									<tbody>
									  <tr>
										<td height="20" style="font-size: 1px; line-height: 1px;">&nbsp;</td>
									  </tr>
									</tbody>
								  </table>
								</td>
							  </tr>
							</tbody>
						  </table>
						</td>
					  </tr>
					</tbody>
				  </table>
				  <div class="pc-gmail-fix" style="white-space: nowrap; font: 15px courier; line-height: 0;">&nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; &nbsp; </div>
				<?php
				$message = ob_get_clean();
				wp_mail($to, $subject, $message );
			}
		}  
	}
	
	public static function ip_block_options_updated($old_value, $value ) {
		if($old_value['ip_send_report_period'] !== $value['ip_send_report_period']){
			wp_clear_scheduled_hook('scheduled_ip_block_email');
			if (! wp_next_scheduled ( 'scheduled_ip_block_email' )) {
				$settings = self::get_settings();
				wp_schedule_event(time(), $settings['ip_send_report_period'], 'scheduled_ip_block_email');
			}
			
		}
	}
}
add_action( 'plugins_loaded', array( 'ip_block', 'init_actions' ) );
register_activation_hook( __FILE__, array( 'ip_block', 'activate' ) );
register_deactivation_hook(__FILE__, array( 'ip_block', 'deactivat'));
endif;
function my_admin_footer_function() {
	//update_option( 'tttttttttttt', $data );
	?><div style="direction:ltr;padding:40px;float: left;min-width: 50vw;display: grid;margin:0 200px"><?
	echo '<style> code, kbd{    display: inline-block;}</style>';
	 highlight_string("<?php\n " . var_export(get_option( 'tttttttttttt',true ), true) . "?>");
	?></div><?php 
	delete_option( 'tttttttttttt');
}
//add_action('admin_footer', 'my_admin_footer_function');

   
